@@ -105,45 +105,45 @@ test_that("mcmc_acf & mcmc_acf_bar throw correct errors", {
 test_that("mcmc_rhat renders correctly", {
   testthat::skip_on_cran()
 
-  rhats <- seq(from = 1, to = 1.20, length = 10)
+  rhats <- seq(from = 1, to = 1.20, length.out = 10)
 
   p_base <- mcmc_rhat(rhats)
-  vdiffr::expect_doppelganger("mcmc rhat (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_rhat (default)", p_base)
 
   p_size <- mcmc_rhat(rhats, size = 3)
-  vdiffr::expect_doppelganger("mcmc rhat (sized)", p_size)
+  vdiffr::expect_doppelganger("mcmc_rhat (sized)", p_size)
 })
 
 test_that("mcmc_rhat_hist renders correctly", {
   testthat::skip_on_cran()
 
-  rhats <- seq(from = 1, to = 1.20, length = 10)
+  rhats <- seq(from = 1, to = 1.20, length.out = 10)
 
   p_base <- mcmc_rhat_hist(rhats)
-  vdiffr::expect_doppelganger("mcmc rhat hist (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_rhat_hist (default)", p_base)
 
   p_binwidth <- mcmc_rhat_hist(rhats, binwidth = .02)
-  vdiffr::expect_doppelganger("mcmc rhat hist (binwidth)", p_binwidth)
+  vdiffr::expect_doppelganger("mcmc_rhat_hist (binwidth)", p_binwidth)
 })
 
 
 test_that("mcmc_neff renders correctly", {
   testthat::skip_on_cran()
 
-  neffs <- seq(from = 0, to = 1, length = 20)
+  neffs <- seq(from = 0, to = 1, length.out = 20)
 
   p_base <- mcmc_neff(neffs)
-  vdiffr::expect_doppelganger("mcmc neff (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_neff (default)", p_base)
 })
 
 test_that("mcmc_neff_hist renders correctly", {
   testthat::skip_on_cran()
 
-  neffs <- seq(from = 0, to = 1, length = 20)
+  neffs <- seq(from = 0, to = 1, length.out = 20)
 
   p_base <- mcmc_neff_hist(neffs)
-  vdiffr::expect_doppelganger("mcmc neff hist (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_neff_hist (default)", p_base)
 
   p_binwidth <- mcmc_neff_hist(neffs, binwidth = .05)
-  vdiffr::expect_doppelganger("mcmc neff hist (binwidth)", p_binwidth)
+  vdiffr::expect_doppelganger("mcmc_neff_hist (binwidth)", p_binwidth)
 })
