@@ -152,6 +152,16 @@ test_that("compute_column_density can use density options (#118)", {
   expect_error(mcmc_areas_data(arr, kernel = stop()))
 })
 
+test_that("probabilities outside of [0,1] cause an error", {
+  expect_error(mcmc_intervals_data(arr, prob = -0.1),
+               "must be in \\[0,1\\]")
+  expect_error(mcmc_intervals_data(arr, prob = 1.1),
+               "must be in \\[0,1\\]")
+  expect_error(mcmc_intervals_data(arr, prob_outer = -0.1),
+               "must be in \\[0,1\\]")
+  expect_error(mcmc_intervals_data(arr, prob_outer = 1.1),
+               "must be in \\[0,1\\]")
+})
 
 test_that("inconsistent probabilities raise warning (#138)", {
   expect_warning(
@@ -169,63 +179,63 @@ test_that("mcmc_intervals renders correctly", {
   testthat::skip_on_cran()
 
   p_base <- mcmc_intervals(vdiff_dframe)
-  vdiffr::expect_doppelganger("mcmc intervals (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_intervals (default)", p_base)
 
   p_outer <- mcmc_intervals(vdiff_dframe, prob_outer = .8)
-  vdiffr::expect_doppelganger("mcmc intervals (outer)", p_outer)
+  vdiffr::expect_doppelganger("mcmc_intervals (outer)", p_outer)
 
   p_inner <- mcmc_intervals(vdiff_dframe, prob = .1)
-  vdiffr::expect_doppelganger("mcmc intervals (inner)", p_inner)
+  vdiffr::expect_doppelganger("mcmc_intervals (inner)", p_inner)
 
-  rhats <- seq(from = 1, to = 1.15, length = 5)
+  rhats <- seq(from = 1, to = 1.15, length.out = 5)
   p_rhats <- mcmc_intervals(vdiff_dframe, rhat = rhats)
-  vdiffr::expect_doppelganger("mcmc intervals (rhats)", p_rhats)
+  vdiffr::expect_doppelganger("mcmc_intervals (rhats)", p_rhats)
 
   p_no_points <- mcmc_intervals(vdiff_dframe, point_est = "none")
-  vdiffr::expect_doppelganger("mcmc intervals (no points)", p_no_points)
+  vdiffr::expect_doppelganger("mcmc_intervals (no points)", p_no_points)
 
   p_mean_points <- mcmc_intervals(vdiff_dframe, point_est = "mean")
-  vdiffr::expect_doppelganger("mcmc intervals (means)", p_mean_points)
+  vdiffr::expect_doppelganger("mcmc_intervals (means)", p_mean_points)
 })
 
 test_that("mcmc_areas renders correctly", {
   testthat::skip_on_cran()
 
   p_base <- mcmc_areas(vdiff_dframe)
-  vdiffr::expect_doppelganger("mcmc areas (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_areas (default)", p_base)
 
   p_equal_height <- mcmc_areas(vdiff_dframe, area_method = "equal height")
-  vdiffr::expect_doppelganger("mcmc areas (equal height)", p_equal_height)
+  vdiffr::expect_doppelganger("mcmc_areas (equal height)", p_equal_height)
 
   p_scaled_height <- mcmc_areas(vdiff_dframe, area_method = "scaled height")
-  vdiffr::expect_doppelganger("mcmc areas (scaled height)", p_scaled_height)
+  vdiffr::expect_doppelganger("mcmc_areas (scaled height)", p_scaled_height)
 
   p_outer <- mcmc_areas(vdiff_dframe, prob_outer = .8)
-  vdiffr::expect_doppelganger("mcmc areas (outer)", p_outer)
+  vdiffr::expect_doppelganger("mcmc_areas (outer)", p_outer)
 
   p_inner <- mcmc_areas(vdiff_dframe, prob = .1)
-  vdiffr::expect_doppelganger("mcmc areas (inner)", p_inner)
+  vdiffr::expect_doppelganger("mcmc_areas (inner)", p_inner)
 
-  rhats <- seq(from = 1, to = 1.15, length = 5)
+  rhats <- seq(from = 1, to = 1.15, length.out = 5)
   p_rhats <- mcmc_areas(vdiff_dframe, rhat = rhats)
-  vdiffr::expect_doppelganger("mcmc areas (rhats)", p_rhats)
+  vdiffr::expect_doppelganger("mcmc_areas (rhats)", p_rhats)
 
   p_no_points <- mcmc_areas(vdiff_dframe, point_est = "none")
-  vdiffr::expect_doppelganger("mcmc areas (no points)", p_no_points)
+  vdiffr::expect_doppelganger("mcmc_areas (no points)", p_no_points)
 
   p_mean_points <- mcmc_areas(vdiff_dframe, point_est = "mean")
-  vdiffr::expect_doppelganger("mcmc areas (means)", p_mean_points)
+  vdiffr::expect_doppelganger("mcmc_areas (means)", p_mean_points)
 })
 
 test_that("mcmc_areas_ridges renders correctly", {
   testthat::skip_on_cran()
 
   p_base <- mcmc_areas_ridges(vdiff_dframe)
-  vdiffr::expect_doppelganger("mcmc areas ridges (default)", p_base)
+  vdiffr::expect_doppelganger("mcmc_areas_ridges (default)", p_base)
 
   p_inner <- mcmc_areas_ridges(vdiff_dframe, prob = .5)
-  vdiffr::expect_doppelganger("mcmc areas ridges (inner)", p_inner)
+  vdiffr::expect_doppelganger("mcmc_areas_ridges (inner)", p_inner)
 
   p_outer <- mcmc_areas_ridges(vdiff_dframe, prob = .5, prob_outer = .95)
-  vdiffr::expect_doppelganger("mcmc areas ridges (outer)", p_outer)
+  vdiffr::expect_doppelganger("mcmc_areas_ridges (outer)", p_outer)
 })
